/***************************************************************************
    begin                : Fri Feb 21 2003
    copyright            : (C) 2003 by Christian Hubinger
    email                : chubinger@irrsinnig.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFAPP_H
#define KMFAPP_H


// TQt includes
#include <tqstring.h>

// KDE includes
#include <tdeapplication.h>

/**
  *@author Christian Hubinger
  */

class TQLabel;
namespace KMF {


class KDE_EXPORT KMFApp : public TDEApplication  {
public: 
	KMFApp();
	~KMFApp();
};

KDE_EXPORT void showSplash();
KDE_EXPORT void closeSplash();
KDE_EXPORT void set_splash_status( const TQString& );

}
#endif
